@@ -466,13 +466,16 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
                 "the individual field arguments should be set."
             )
 
-        # The request isn't a proto-plus wrapped type,
-        # so it must be constructed via keyword expansion.
         if isinstance(request, dict):
+            # The request isn't a proto-plus wrapped type,
+            # so it must be constructed via keyword expansion.
             request = iam_policy.SetIamPolicyRequest(**request)
-
         elif not request:
-            request = iam_policy.SetIamPolicyRequest(resource=resource,)
+            # Null request, just make one.
+            request = iam_policy.SetIamPolicyRequest()
+
+            if resource is not None:
+                request.resource = resource
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -598,13 +601,16 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
                 "the individual field arguments should be set."
             )
 
-        # The request isn't a proto-plus wrapped type,
-        # so it must be constructed via keyword expansion.
         if isinstance(request, dict):
+            # The request isn't a proto-plus wrapped type,
+            # so it must be constructed via keyword expansion.
             request = iam_policy.GetIamPolicyRequest(**request)
-
         elif not request:
-            request = iam_policy.GetIamPolicyRequest(resource=resource,)
+            # Null request, just make one.
+            request = iam_policy.GetIamPolicyRequest()
+
+            if resource is not None:
+                request.resource = resource
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -684,15 +690,19 @@ class ContainerAnalysisClient(metaclass=ContainerAnalysisClientMeta):
                 "the individual field arguments should be set."
             )
 
-        # The request isn't a proto-plus wrapped type,
-        # so it must be constructed via keyword expansion.
         if isinstance(request, dict):
+            # The request isn't a proto-plus wrapped type,
+            # so it must be constructed via keyword expansion.
             request = iam_policy.TestIamPermissionsRequest(**request)
-
         elif not request:
-            request = iam_policy.TestIamPermissionsRequest(
-                resource=resource, permissions=permissions,
-            )
+            # Null request, just make one.
+            request = iam_policy.TestIamPermissionsRequest()
+
+            if resource is not None:
+                request.resource = resource
+
+            if permissions:
+                request.permissions.extend(permissions)
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
